define(
//begin v1.x content
{
	"days-standAlone-short": [
		"dom.",
		"seg.",
		"ter.",
		"qua.",
		"qui.",
		"sex.",
		"sáb."
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-quarter-relative+-1": "trimestre passado",
	"field-day-narrow-relative+0": "hoje",
	"field-day-narrow-relative+1": "amanhã",
	"field-day-short-relative+0": "hoje",
	"field-day-short-relative+1": "amanhã",
	"dateFormatItem-GyMMMEd": "E, d 'de' MMM 'de' y G",
	"dateFormatItem-MMMEd": "E, d 'de' MMM",
	"field-dayperiod-short": "am/pm",
	"eraNarrow": "BE",
	"days-format-short": [
		"dom.",
		"seg.",
		"ter.",
		"qua.",
		"qui.",
		"sex.",
		"sáb."
	],
	"dateFormat-long": "d 'de' MMMM 'de' y G",
	"months-format-wide": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro",
		"novembro",
		"dezembro"
	],
	"dateFormatItem-yyyyQQQ": "QQQQ 'de' y G",
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "da tarde",
	"dateFormat-full": "EEEE, d 'de' MMMM 'de' y G",
	"dateFormatItem-yyyyMEd": "E, dd/MM/y GGGGG",
	"field-mon-short-relative+-1": "segunda passada",
	"field-day-short-relative+-1": "ontem",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-standAlone-wide-pm": "tarde",
	"dayPeriods-format-abbr-am": "a.m.",
	"months-standAlone-wide": [
		"janeiro",
		"fevereiro",
		"março",
		"abril",
		"maio",
		"junho",
		"julho",
		"agosto",
		"setembro",
		"outubro",
		"novembro",
		"dezembro"
	],
	"dayPeriods-standAlone-abbr-am": "a.m.",
	"quarters-format-wide": [
		"1.º trimestre",
		"2.º trimestre",
		"3.º trimestre",
		"4.º trimestre"
	],
	"dateFormatItem-yyyyMMMM": "MMMM 'de' y G",
	"field-day-narrow-relative+-1": "ontem",
	"months-format-abbr": [
		"jan.",
		"fev.",
		"mar.",
		"abr.",
		"mai.",
		"jun.",
		"jul.",
		"ago.",
		"set.",
		"out.",
		"nov.",
		"dez."
	],
	"field-sat-short-relative+-1": "sábado passado",
	"dayPeriods-standAlone-narrow-am": "a.m.",
	"field-minute-narrow": "min",
	"dateFormatItem-GyMMMd": "d 'de' MMM 'de' y G",
	"quarters-format-abbr": [
		"1.º trimestre",
		"2.º trimestre",
		"3.º trimestre",
		"4.º trimestre"
	],
	"quarters-standAlone-wide": [
		"1.º trimestre",
		"2.º trimestre",
		"3.º trimestre",
		"4.º trimestre"
	],
	"field-mon-short-relative+0": "esta segunda",
	"dateFormatItem-Gy": "y G",
	"field-mon-short-relative+1": "próxima segunda",
	"dateFormatItem-yyyyMMMEd": "E, d/MM/y G",
	"field-wed-short-relative+-1": "quarta passada",
	"days-standAlone-wide": [
		"domingo",
		"segunda-feira",
		"terça-feira",
		"quarta-feira",
		"quinta-feira",
		"sexta-feira",
		"sábado"
	],
	"dateFormatItem-yyyyMMM": "MM/y G",
	"dateFormatItem-yyyyMMMd": "d/MM/y G",
	"dateFormatItem-MMMMd": "d 'de' MMMM",
	"field-tue-short-relative+0": "esta terça",
	"field-tue-short-relative+1": "próxima terça",
	"field-minute-short": "min",
	"field-wed-short-relative+0": "esta quarta",
	"field-wed-short-relative+1": "próxima quarta",
	"quarters-standAlone-abbr": [
		"1.º trimestre",
		"2.º trimestre",
		"3.º trimestre",
		"4.º trimestre"
	],
	"field-dayperiod": "am/pm",
	"days-standAlone-abbr": [
		"domingo",
		"segunda",
		"terça",
		"quarta",
		"quinta",
		"sexta",
		"sábado"
	],
	"dateTimeFormat-long": "{1} 'às' {0}",
	"dayPeriods-format-narrow-am": "a.m.",
	"dateFormatItem-MMMd": "d 'de' MMM",
	"field-quarter-relative+0": "este trimestre",
	"field-dayperiod-narrow": "am/pm",
	"field-quarter-relative+1": "próximo trimestre",
	"dateFormatItem-MEd": "E, dd/MM",
	"field-zone-short": "fuso horário",
	"dateTimeFormat-full": "{1} 'às' {0}",
	"days-format-wide": [
		"domingo",
		"segunda-feira",
		"terça-feira",
		"quarta-feira",
		"quinta-feira",
		"sexta-feira",
		"sábado"
	],
	"field-second-narrow": "s",
	"dateFormatItem-y": "y G",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-thu-short-relative+0": "esta quinta",
	"field-thu-short-relative+1": "próxima quinta",
	"dayPeriods-format-abbr-pm": "p.m.",
	"field-quarter-narrow-relative+0": "este trim.",
	"field-quarter-narrow-relative+1": "próximo trim.",
	"days-format-abbr": [
		"domingo",
		"segunda",
		"terça",
		"quarta",
		"quinta",
		"sexta",
		"sábado"
	],
	"dayPeriods-standAlone-abbr-pm": "p.m.",
	"eraNames": [
		"BE"
	],
	"days-format-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"dateFormatItem-yyyyMd": "dd/MM/y GGGGG",
	"field-zone-narrow": "fuso horário",
	"days-standAlone-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"dayPeriods-standAlone-narrow-pm": "p.m.",
	"field-quarter-short-relative+0": "este trim.",
	"field-quarter-short-relative+1": "próximo trim.",
	"dayPeriods-format-wide-am": "da manhã",
	"dayPeriods-standAlone-wide-am": "manhã",
	"field-fri-short-relative+-1": "sexta passada",
	"field-quarter-short-relative+-1": "trim. passado",
	"dateFormat-short": "d/M/y G",
	"field-second-short": "s",
	"field-fri-short-relative+0": "esta sexta",
	"field-fri-short-relative+1": "próxima sexta",
	"field-quarter-narrow-relative+-1": "trim. passado",
	"dateFormatItem-Ed": "E, d",
	"field-sat-short-relative+0": "este sábado",
	"field-sat-short-relative+1": "próximo sábado",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyM": "MM/y GGGGG",
	"dayPeriods-format-narrow-pm": "p.m.",
	"dateFormatItem-yyyyQQQQ": "QQQQ 'de' y G",
	"dateTimeFormat-short": "{1}, {0}",
	"field-sun-short-relative+-1": "domingo passado",
	"field-thu-short-relative+-1": "quinta passada",
	"field-tue-short-relative+-1": "terça passada",
	"dateFormatItem-GyMMM": "MMM 'de' y G",
	"dateFormatItem-yyyy": "y G",
	"field-sun-short-relative+0": "este domingo",
	"field-sun-short-relative+1": "próximo domingo"
}
//end v1.x content
);